@@ -1,7 +1,7 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
  *
- * Copyright (C) 2000-2011 by Alfons Hoogervorst & The Claws Mail Team.
+ * Copyright (C) 2000-2012 by Alfons Hoogervorst & The Claws Mail Team.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,8 +35,8 @@
 #  include <wctype.h>
 #endif
 
-#include "addrindex.h"
 #include "addr_compl.h"
+#include "addritem.h"
 #include "utils.h"
 #include "prefs_common.h"
 #include "claws.h"
@@ -44,6 +44,12 @@
 #include "gtkutils.h"
 #include <pthread.h>
 
+#ifndef USE_NEW_ADDRBOOK
+	#include "addrindex.h"
+#else
+	#include "addressbook-dbus.h"
+#endif
+
 /*!
  *\brief	For the GtkListStore
  */
@@ -286,8 +292,18 @@ static void read_address_book(gchar *folderpath) {
 	free_all_addresses();
 	free_completion_list();
 
+#ifndef USE_NEW_ADDRBOOK
 	addrindex_load_completion( add_address, folderpath );
-
+#else
+	GError* error = NULL;
+	
+	addrcompl_initialize();
+	if (! addrindex_dbus_load_completion(add_address, &error)) {
+		g_warning("Failed to populate address completion list");
+        g_error_free(error);
+		return;
+	}
+#endif
 	/* plugins may hook in here to modify/extend the completion list */
 	hooks_invoke(ADDDRESS_COMPLETION_BUILD_ADDRESS_LIST_HOOKLIST, &g_address_list);
 
@@ -753,8 +769,9 @@ static CompletionWindow *addrcompl_create_window( void ) {
  */
 static void addrcompl_destroy_window( CompletionWindow *cw ) {
 	/* Stop all searches currently in progress */
+#ifndef USE_NEW_ADDRBOOK
 	addrindex_stop_search( _queryID_ );
-
+#endif
 	/* Remove idler function... or application may not terminate */
 	if( _completionIdleID_ != 0 ) {
 		g_source_remove( _completionIdleID_ );
@@ -849,7 +866,7 @@ static void addrcompl_resize_window( CompletionWindow *cw ) {
 	gtk_widget_hide_all( cw->window );
 	gtk_widget_show_all( cw->window );
 	gtk_widget_size_request( cw->list_view, &r );
-printf("%d  + %d < %d\n", y, r.height, gdk_screen_height());
+
 	/* Adjust window height to available screen space */
 	if( y + r.height > gdk_screen_height())
 		r.height = gdk_screen_height() - y;
@@ -975,6 +992,7 @@ static gboolean addrcompl_idle( gpointer data ) {
  *                   criteria.
  * \param data       Query data.
  */
+#ifndef USE_NEW_ADDRBOOK
 static gint addrcompl_callback_entry(
 	gpointer sender, gint queryID, GList *listEMail, gpointer data )
 {
@@ -1000,6 +1018,7 @@ static gint addrcompl_callback_entry(
 
 	return 0;
 }
+#endif
 
 /**
  * Clear the display queue.
@@ -1045,6 +1064,7 @@ static void addrcompl_load_local( void ) {
  * Start the search.
  */
 static void addrcompl_start_search( void ) {
+#ifndef USE_NEW_ADDRBOOK
 	gchar *searchTerm;
 
 	searchTerm = g_strdup( _compWindow_->searchTerm );
@@ -1053,6 +1073,7 @@ static void addrcompl_start_search( void ) {
 	_queryID_ = addrindex_setup_search(
 		searchTerm, NULL, addrcompl_callback_entry );
 	g_free( searchTerm );
+#endif
 	/* g_print( "addrcompl_start_search::queryID=%d\n", _queryID_ ); */
 
 	/* Load local stuff */
@@ -1063,7 +1084,11 @@ static void addrcompl_start_search( void ) {
 		g_idle_add( (GSourceFunc) addrcompl_idle, NULL );
 	/* g_print( "addrindex_start_search::queryID=%d\n", _queryID_ ); */
 
+#ifndef USE_NEW_ADDRBOOK
 	addrindex_start_search( _queryID_ );
+#else
+	
+#endif
 }
 
 /**
