@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -80,6 +80,8 @@ const gchar const *plugin_licence_tokens[] = {
   "GPL3+", "GPLv3+", "GPL3", "GPLv3",
   "GPL2+", "GPLv2+",
   "Apache2.0", "Apache 2.0", "Apache v2.0",
+  "2-clause BSD", "Simplified BSD", "FreeBSD",
+  "3-clause BSD", "New BSD", "Modified BSD",
   NULL
 };
 
