@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,10 @@
 #include "codeconv.h"
 #include "menu.h"
 #include "textview.h"
+#include "main.h"
+
+extern SessionStats session_stats;
+static GtkTextBuffer *stats_text_buffer;
 
 static GtkWidget *window;
 static gchar* uri_hover = NULL;
@@ -64,6 +68,7 @@ static gboolean about_textview_leave_notify(GtkWidget *widget,
 static void about_size_allocate_cb(GtkWidget *widget,
 				   	GtkAllocation *allocation);
 static void about_textview_uri_update(GtkWidget *textview, gint x, gint y);
+static void about_update_stats(void);
 
 static GtkWidget *link_popupmenu;
 
@@ -72,8 +77,10 @@ void about_show(void)
 {
 	if (!window)
 		about_create();
-	else 
+	else {
+		about_update_stats();
 		gtk_window_present(GTK_WINDOW(window));
+	}
 	
 }
 
@@ -143,7 +150,7 @@ static GtkWidget *about_create_child_page_info(void)
 				NULL);
 #ifdef GENERIC_UMPC
 	gtk_text_buffer_insert(buffer, &iter, _(
-				"\n\nCopyright (C) 1999-2011\nThe Claws Mail Team\n"
+				"\n\nCopyright (C) 1999-2012\nThe Claws Mail Team\n"
 				" and Hiroyuki Yamamoto"), -1);
 #endif
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (_("\n\nSystem Information\n")), -1,
@@ -219,7 +226,7 @@ static GtkWidget *about_create_child_page_authors(void)
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
 	gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
 
-	/* init formatting tag: indentation  for list items */
+	/* init formatting tag: indentation for list items */
 	gtk_text_buffer_create_tag(buffer, "indented-list-item",
 				"indent", 8,
 				NULL);
@@ -633,6 +640,101 @@ static GtkWidget *about_create_child_page_release_notes(void)
 	return scrolledwin;
 }
 
+static GtkWidget *about_create_child_page_session_stats(void)
+{
+	GtkWidget *scrolledwin;
+	GtkWidget *text;
+	GtkTextIter iter;
+
+	scrolledwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwin),
+			GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolledwin),
+			GTK_SHADOW_IN);
+	text = gtk_text_view_new();
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text), GTK_WRAP_WORD);
+	gtk_text_view_set_left_margin(GTK_TEXT_VIEW(text), 6);
+	gtk_text_view_set_right_margin(GTK_TEXT_VIEW(text), 6);
+	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text), FALSE);
+	gtk_container_add(GTK_CONTAINER(scrolledwin), text);
+
+	stats_text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+
+	gtk_text_buffer_get_iter_at_offset(stats_text_buffer, &iter, 0);
+	gtk_text_buffer_create_tag(stats_text_buffer, "indented-list-item",
+				"indent", 8,
+				NULL);
+	gtk_text_buffer_create_tag(stats_text_buffer, "underlined-list-title",
+				"underline", PANGO_UNDERLINE_SINGLE,
+				NULL);
+	gtk_text_buffer_create_tag(stats_text_buffer, "bold", "weight", PANGO_WEIGHT_BOLD,
+				   NULL);
+
+	about_update_stats();
+
+	return scrolledwin;
+}
+
+static void about_update_stats(void)
+{
+	if (stats_text_buffer != NULL)
+	{
+		GtkTextIter start, end, iter;
+		gchar buf[1024];
+
+		gtk_text_buffer_get_start_iter(stats_text_buffer, &start);
+		gtk_text_buffer_get_end_iter(stats_text_buffer, &end);
+		gtk_text_buffer_delete(stats_text_buffer, &start, &end);
+
+		gtk_text_buffer_get_iter_at_offset(stats_text_buffer, &iter, 0);
+
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter,
+				(_("Session statistics\n")), -1,
+				"underlined-list-title", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("Started: %s\n"),
+					ctime(&session_stats.time_started));
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", NULL);
+
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter,
+				(_("Incoming traffic\n")), -1,
+				"underlined-list-title", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("Received messages: %d\n"),
+					session_stats.received);
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", "bold", NULL);
+
+		gtk_text_buffer_insert(stats_text_buffer, &iter, "\n", 1);
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter,
+				(_("Outgoing traffic\n")), -1,
+				"underlined-list-title", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("New/redirected messages: %d\n"),
+					session_stats.sent);
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("Replied messages: %d\n"),
+					session_stats.replied);
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("Forwarded messages: %d\n"),
+					session_stats.forwarded);
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", NULL);
+
+		g_snprintf(buf, sizeof(buf), _("Total outgoing messages: %d\n"),
+					(session_stats.sent + session_stats.replied +
+					 session_stats.forwarded));
+		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+				"indented-list-item", "bold", NULL);
+	} 
+}
+
 static void about_create(void)
 {
 	GtkWidget *vbox1;
@@ -648,6 +750,8 @@ static void about_create(void)
 	GtkWidget *close_button;
 	static GdkGeometry geometry;
 
+	stats_text_buffer = NULL;
+
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "about");
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER_ALWAYS);
 	gtk_window_set_title(GTK_WINDOW(window), _("About Claws Mail"));
@@ -708,7 +812,7 @@ static void about_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 0);
 #ifndef GENERIC_UMPC
 	label = gtk_label_new
-		(_("Copyright (C) 1999-2011\nThe Claws Mail Team\n"
+		(_("Copyright (C) 1999-2012\nThe Claws Mail Team\n"
 		 "and Hiroyuki Yamamoto"));
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
@@ -751,6 +855,12 @@ static void about_create(void)
 				gtk_label_new_with_mnemonic(_("_Release Notes")));
 	}
 
+	if ((scrolledwin = about_create_child_page_session_stats()) != NULL) {
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+				scrolledwin,
+				gtk_label_new_with_mnemonic(_("_Statistics")));
+	}
+
 	gtk_box_pack_start(GTK_BOX(vbox1), notebook, TRUE, TRUE, 0);
 
 	gtkut_stock_button_set_create(&confirm_area, &close_button, GTK_STOCK_CLOSE,
