@@ -1,5 +1,5 @@
 /*
- * This file Copyright (C) 2005-2011 Paul Mangan <paul@claws-mail.org>
+ * This file Copyright (C) 2005-2012 Paul Mangan <paul@claws-mail.org>
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,7 @@ StockPixmap legend_icons[ICONS] = {
 	STOCK_PIXMAP_UNREAD,
 	STOCK_PIXMAP_REPLIED, 
 	STOCK_PIXMAP_FORWARDED, 
+	STOCK_PIXMAP_REPLIED_AND_FORWARDED, 
 	STOCK_PIXMAP_IGNORETHREAD,
 	STOCK_PIXMAP_WATCHTHREAD,
 	STOCK_PIXMAP_SPAM,
@@ -63,6 +64,7 @@ static gchar *legend_icon_desc[] = {
 	N_("Unread message"),
 	N_("Message has been replied to"),
 	N_("Message has been forwarded"),
+	N_("Message has been forwarded and replied to"),
 	N_("Message is in an ignored thread"),
 	N_("Message is in a watched thread"),
 	N_("Message is spam"),
