@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2012 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -504,6 +504,7 @@ static gchar *search_descr_strings[] = {
 	"E S",	 N_("true if execute \"S\" succeeds"),
 	"f S",	 N_("messages originating from user S"),
 	"F",	 N_("forwarded messages"),
+	"ha",	 N_("messages which have attachments"),
 	"h S",	 N_("messages which contain header S"),
 	"i S",	 N_("messages which contain S in Message-ID header"),
 	"I S",	 N_("messages which contain S in In-Reply-To header"),
@@ -1180,6 +1181,7 @@ static gchar *expand_search_string(const gchar *search_string)
 		{ "f",	"from",				1,	TRUE,	TRUE  },
 		{ "F",	"forwarded",			0,	FALSE,	FALSE },
 		{ "h",	"headers_part",			1,	TRUE,	TRUE  },
+		{ "ha",	"has_attachments",		0,	FALSE,	FALSE },
 		{ "i",	"header \"Message-ID\"",	1,	TRUE,	TRUE  },
 		{ "I",	"inreplyto",			1,	TRUE,	TRUE  },
 		{ "k",	"colorlabel",			1,	FALSE,	FALSE },
