@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2003-2009 Match Grun and the Claws Mail team
+ * Copyright (C) 2003-2012 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -294,13 +294,17 @@ void ldapctl_set_matching_option( LdapControl* ctl, const gint value ) {
  * \param value <i>TRUE</i> to enable TLS.
  */
 void ldapctl_set_tls( LdapControl* ctl, const gboolean value ) {
+#ifdef USE_LDAP_TLS
 	ctl->enableTLS = value;
 	debug_print("setting TLS: %d\n", ctl->enableTLS);
+#endif
 }
 
 void ldapctl_set_ssl( LdapControl* ctl, const gboolean value ) {
+#ifdef USE_LDAP_TLS
 	ctl->enableSSL = value;
 	debug_print("setting SSL: %d\n", ctl->enableSSL);
+#endif
 }
 
 /**
@@ -628,8 +632,15 @@ gchar *ldapctl_format_criteria( LdapControl *ctl, const gchar *searchVal ) {
 			/* Subsequent time through */
 			gchar *crit;
 
-			/* Format query criteria */
-			crit = g_strdup_printf( criteriaFmt, attr, searchVal );
+			debug_print("crit: %s\n", searchVal);
+			/* fix bug when doing a search any */
+			if (strcmp("*@", searchVal) == 0) {
+			    crit = g_strdup_printf( "(%s=*)", attr );
+			}
+			else {
+			    /* Format query criteria */
+			    crit = g_strdup_printf( criteriaFmt, attr, searchVal );
+			}
 
 			/* Append to existing criteria */			
 			g_free( p2 );
@@ -639,7 +650,13 @@ gchar *ldapctl_format_criteria( LdapControl *ctl, const gchar *searchVal ) {
 		}
 		else {
 			/* First time through - Format query criteria */
-			p2 = g_strdup_printf( criteriaFmt, attr, searchVal );
+                        /* fix bug when doing a search any */
+			if (strcmp("*@", searchVal) == 0) {
+			    p2 = g_strdup_printf( "(%s=*)", attr );
+			}
+			else {
+			    p2 = g_strdup_printf( criteriaFmt, attr, searchVal );
+			}
 		}
 	}
 
