@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2003-2009 Michael Rasmussen and the Claws Mail team
+ * Copyright (C) 2003-2012 Michael Rasmussen and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,8 +43,6 @@
 #include <glib/gi18n.h>
 #include <sys/time.h>
 #include <string.h>
-#include <ldap.h>
-#include <lber.h>
 
 #include "ldapupdate.h"
 #include "mgutils.h"
@@ -307,82 +305,6 @@ ItemPerson *ldapsvr_get_contact(LdapServer *server, gchar *uid) {
 	return NULL;
 }
 
-/**
- * Connect to LDAP server.
- * \param  ctl Control object to process.
- * \return LDAP Resource to LDAP.
- */
-LDAP *ldapsvr_connect(LdapControl *ctl) {
-	LDAP *ld = NULL;
-	gint rc;
-	gint version;
-	gchar *uri = NULL;
-	gchar *pwd;
-
-	cm_return_val_if_fail(ctl != NULL, NULL);
-
-	ldapsrv_set_options (ctl->timeOut, NULL);
-	uri = g_strdup_printf("ldap%s://%s:%d",
-				ctl->enableSSL?"s":"",
-				ctl->hostName, ctl->port);
-	ldap_initialize(&ld, uri);
-	g_free(uri);
-
-	if (ld == NULL)
-		return NULL;
-
-
-	debug_print("connected to LDAP host %s on port %d\n", ctl->hostName, ctl->port);
-
-#ifdef USE_LDAP_TLS
-	/* Handle TLS */
-	version = LDAP_VERSION3;
-	rc = ldap_set_option(ld, LDAP_OPT_PROTOCOL_VERSION, &version);
-	if (rc == LDAP_OPT_SUCCESS) {
-		ctl->version = LDAP_VERSION3;
-	}
-
-	if (ctl->version == LDAP_VERSION3) {
-		if (ctl->enableTLS && !ctl->enableSSL) {
-			rc = ldap_start_tls_s(ld, NULL, NULL);
-			
-			if (rc != LDAP_SUCCESS) {
-				g_printerr("LDAP Error(tls): ldap_simple_bind_s: %s\n",
-					ldap_err2string(rc));
-				return NULL;
-			}
-		}
-	}
-#endif
-
-	/* Bind to the server, if required */
-	if (ctl->bindDN) {
-		if (* ctl->bindDN != '\0') {
-			pwd = ldapctl_get_bind_password(ctl);
-			rc = claws_ldap_simple_bind_s(ld, ctl->bindDN, pwd);
-			if (rc != LDAP_SUCCESS) {
-				g_printerr("bindDN: %s, bindPass: %s\n", ctl->bindDN, pwd);
-				g_printerr("LDAP Error(bind): ldap_simple_bind_s: %s\n",
-					ldap_err2string(rc));
-				g_free(pwd);
-				return NULL;
-			}
-			g_free(pwd);
-		}
-	}
-	return ld;
-}
-
-/**
- * Disconnect to LDAP server.
- * \param ld Resource to LDAP.
- */
-void ldapsvr_disconnect(LDAP *ld) {
-	/* Disconnect */
-	cm_return_if_fail(ld != NULL);
-	ldap_unbind_ext(ld, NULL, NULL);
-}
-
 /**
  * Create an initial Rdn structure
  *
@@ -460,17 +382,16 @@ Rdn *ldapsvr_modify_dn(GHashTable *hash, gchar *dn) {
 		return NULL;
 	}
 	rdn = rdn_create();
-	rdn->value = g_strdup(val);
-	rdn->attribute = g_strdup(compare);
-	g_free(val);
+	rdn->value = val;
+	rdn->attribute = compare;
+
 	if (strcmp("mail", rdn->attribute) == 0) {
 		GList *list = g_hash_table_lookup(hash, rdn->attribute);
 		while (list) {
 			EmailKeyValue *item = list->data;
-			compare = g_strdup((gchar *) item->mail);
+			compare = (gchar *) item->mail;
 			if (strcmp(compare, rdn->value) == 0) {
 				update_rdn(rdn, compare, rest);
-				g_free(compare);
 				return rdn;
 			}
 			list = g_list_next(list);
@@ -479,12 +400,10 @@ Rdn *ldapsvr_modify_dn(GHashTable *hash, gchar *dn) {
 		if (strcmp(compare, rdn->attribute) != 0) {
 	 		/* RDN changed. Find new */
 			update_rdn(rdn, compare, rest);
-			g_free(compare);
 			return rdn;
 		}
 		else {
 			/* We cannot remove dn */
-			g_free(compare);
 			rdn_free(rdn);
 			return NULL;
 		}
@@ -741,7 +660,7 @@ void ldapsvr_compare_attr(LDAP *ld, gchar *dn, gint cnt, LDAPMod *mods[]) {
 #endif
 
 		g_printerr("ldap_compare for (%s:%s)\" failed[0x%x]: %s\n",
-        	mods[i]->mod_type, value, rc, ldap_err2string(rc));
+        	mods[i]->mod_type, value, rc, ldaputil_get_error(ld));
 		g_free(value);
 	}
 }
@@ -776,19 +695,10 @@ int ldapsvr_compare_manual_attr(LDAP *ld, LdapServer *server, gchar *dn, char *a
 	attrkeyvalue_free(mail);
 	if (ctl) {
 
-#ifdef OPEN_LDAP_API_AT_LEAST_3000
-
 		rc = ldap_search_ext_s(ld, ctl->baseDN, LDAP_SCOPE_ONELEVEL, filter, NULL, 0, NULL, NULL, NULL, 0, &res);
 
-#else
-
-		/* This is deprecated as of OpenLDAP-2.3.0 */
-		rc = ldap_search_s(ld, ctl->baseDN, LDAP_SCOPE_ONELEVEL, filter, NULL, 0, &res);
-
-#endif
-
 		if (rc) {
-			g_printerr("ldap_search for attr=%s\" failed[0x%x]: %s\n",attr, rc, ldap_err2string(rc));
+			g_printerr("ldap_search for attr=%s\" failed[0x%x]: %s\n",attr, rc, ldaputil_get_error(ld));
 			retVal = -2;
 		}
 		else {
@@ -883,7 +793,7 @@ int ldapsvr_deside_operation(LDAP *ld, LdapServer *server, char *dn, char *attr,
 #endif
 
 	debug_print("ldap_compare for (%s:%s)\" error_code[0x%x]: %s\n",
-       	attr, value, rc, ldap_err2string(rc));
+       	attr, value, rc, ldaputil_get_error(ld));
 	switch (rc) {
 		case LDAP_COMPARE_FALSE: 
 			if (dummy)
@@ -1025,7 +935,7 @@ void ldapsvr_handle_other_attributes(LDAP *ld, LdapServer *server, char *dn, GHa
 				server->retVal = LDAPRC_ALREADY_EXIST;
 				break;
 			default:
-				g_printerr("ldap_modify for dn=%s\" failed[0x%x]: %s\n", dn, rc, ldap_err2string(rc));
+				g_printerr("ldap_modify for dn=%s\" failed[0x%x]: %s\n", dn, rc, ldaputil_get_error(ld));
 				if (rc == 0x8)
 					server->retVal = LDAPRC_STRONG_AUTH;
 				else
@@ -1168,7 +1078,7 @@ void ldapsvr_add_contact(LdapServer *server, GHashTable *contact) {
 				break;
 			default:
 				g_printerr("ldap_modify for dn=%s\" failed[0x%x]: %s\n",
-						base_dn, rc, ldap_err2string(rc));
+						base_dn, rc, ldaputil_get_error(ld));
 				if (rc == 0x8)
 					server->retVal = LDAPRC_STRONG_AUTH;
 				else
@@ -1241,7 +1151,7 @@ void ldapsvr_update_contact(LdapServer *server, GHashTable *contact) {
 			else {
 				g_printerr("Current dn: %s\n", dn);
 				g_printerr("new dn: %s\n", newRdn);
-				g_printerr("LDAP Error(ldap_modrdn2_s) failed[0x%x]: %s\n", rc, ldap_err2string(rc));
+				g_printerr("LDAP Error(ldap_modrdn2_s) failed[0x%x]: %s\n", rc, ldaputil_get_error(ld));
 				g_free(newRdn);
 				clean_up(ld, server, contact);
 				return;
@@ -1397,7 +1307,7 @@ void ldapsvr_update_contact(LdapServer *server, GHashTable *contact) {
 		rc = ldap_modify_ext_s(ld, dn, mods, NULL, NULL);
 		if (rc) {
 			g_printerr("ldap_modify for dn=%s\" failed[0x%x]: %s\n",
-                    dn, rc, ldap_err2string(rc));
+                    dn, rc, ldaputil_get_error(ld));
 			server->retVal = LDAPRC_NAMING_VIOLATION;
 		}
 		if (mail)
@@ -1438,7 +1348,7 @@ void ldapsvr_delete_contact(LdapServer *server, GHashTable *contact) {
 	rc = ldap_delete_ext_s(ld, dn, NULL, NULL);
 	if (rc) {
 		g_printerr("ldap_modify for dn=%s\" failed[0x%x]: %s\n",
-				dn, rc, ldap_err2string(rc));
+				dn, rc, ldaputil_get_error(ld));
 		server->retVal = LDAPRC_NODN;
 	}
 	clean_up(ld, server, contact);
