@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -93,7 +93,11 @@
 #include "manage_window.h"
 #include "alertpanel.h"
 #include "statusbar.h"
-#include "addressbook.h"
+#ifndef USE_NEW_ADDRBOOK
+	#include "addressbook.h"
+#else
+	#include "addressbook-dbus.h"
+#endif
 #include "compose.h"
 #include "folder.h"
 #include "setup.h"
@@ -195,7 +199,7 @@ static struct RemoteCmd {
 	gboolean receive_all;
 	gboolean compose;
 	const gchar *compose_mailto;
-	GPtrArray *attach_files;
+	GList *attach_files;
 	gboolean search;
 	const gchar *search_folder;
 	const gchar *search_type;
@@ -203,6 +207,8 @@ static struct RemoteCmd {
 	gboolean search_recursive;
 	gboolean status;
 	gboolean status_full;
+	gboolean statistics;
+	gboolean reset_statistics;
 	GPtrArray *status_folders;
 	GPtrArray *status_full_folders;
 	gboolean send;
@@ -215,6 +221,10 @@ static struct RemoteCmd {
 	const gchar *target;
 } cmd;
 
+SessionStats session_stats;
+
+static void reset_statistics(void);
+		
 static void parse_cmd_opt(int argc, char *argv[]);
 
 static gint prohibit_duplicate_launch	(void);
@@ -225,7 +235,7 @@ static void lock_socket_input_cb	(gpointer	   data,
 					 GIOCondition      condition);
 
 static void open_compose_new		(const gchar	*address,
-					 GPtrArray	*attach_files);
+					 GList		*attach_files);
 
 static void send_queue			(void);
 static void initial_processing		(FolderItem *item, gpointer data);
@@ -1027,6 +1037,16 @@ static void install_dbus_status_handler(void)
 }
 #endif
 
+static void reset_statistics(void)
+{
+	/* (re-)initialize session statistics */
+	session_stats.received = 0;
+	session_stats.sent = 0;
+	session_stats.replied = 0;
+	session_stats.forwarded = 0;
+	session_stats.time_started = time(NULL);
+}
+		
 int main(int argc, char *argv[])
 {
 #ifdef MAEMO
@@ -1102,7 +1122,8 @@ int main(int argc, char *argv[])
 		return 0;
 	}
 
-	if (cmd.status || cmd.status_full || cmd.search) {
+	if (cmd.status || cmd.status_full || cmd.search ||
+		cmd.statistics || cmd.reset_statistics) {
 		puts("0 Claws Mail not running.");
 		lock_socket_remove();
 		return 0;
@@ -1113,6 +1134,8 @@ int main(int argc, char *argv[])
 	if (!g_thread_supported())
 		g_thread_init(NULL);
 
+	reset_statistics();
+	
 	gtk_set_locale();
 	gtk_init(&argc, &argv);
 
@@ -1315,8 +1338,18 @@ int main(int argc, char *argv[])
 	prefs_actions_read_config();
 	prefs_display_header_read_config();
 	/* prefs_filtering_read_config(); */
+#ifndef USE_NEW_ADDRBOOK
 	addressbook_read_file();
-
+#else
+	g_clear_error(&error);
+	if (! addressbook_start_service(&error)) {
+		g_warning("%s", error->message);
+		g_clear_error(&error);
+	}
+	else {
+		addressbook_install_hooks(&error);
+	}
+#endif
 	gtkut_widget_init();
 	stock_pixbuf_gdk(NULL, STOCK_PIXMAP_CLAWS_MAIL_ICON, &icon);
 	gtk_window_set_default_icon(icon);
@@ -1622,8 +1655,8 @@ int main(int argc, char *argv[])
 		open_compose_new(cmd.compose_mailto, cmd.attach_files);
 	}
 	if (cmd.attach_files) {
-		ptr_array_free_strings(cmd.attach_files);
-		g_ptr_array_free(cmd.attach_files, TRUE);
+		list_free_strings(cmd.attach_files);
+		g_list_free(cmd.attach_files);
 		cmd.attach_files = NULL;
 	}
 	if (cmd.subscribe) {
@@ -1719,8 +1752,9 @@ static void exit_claws(MainWindow *mainwin)
 
 	prefs_common_write_config();
 	account_write_config_all();
+#ifndef USE_NEW_ADDRBOOK
 	addressbook_export_to_file();
-
+#endif
 	filename = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, MENU_RC, NULL);
 	gtk_accel_map_save(filename);
 	g_free(filename);
@@ -1759,8 +1793,9 @@ static void exit_claws(MainWindow *mainwin)
 
 	prefs_toolbar_done();
 
+#ifndef USE_NEW_ADDRBOOK
 	addressbook_destroy();
-
+#endif
 	prefs_themes_done();
 	prefs_fonts_done();
 	prefs_ext_prog_done();
@@ -1875,6 +1910,7 @@ static GString * parse_cmd_compose_from_file(const gchar *fn)
 
 static void parse_cmd_opt(int argc, char *argv[])
 {
+	AttachInfo *ainfo;
 	gint i;
 
 	for (i = 1; i < argc; i++) {
@@ -1913,9 +1949,6 @@ static void parse_cmd_opt(int argc, char *argv[])
 			gchar *file = NULL;
 
 			while (p && *p != '\0' && *p != '-') {
-				if (!cmd.attach_files) {
-					cmd.attach_files = g_ptr_array_new();
-				}
 				if ((file = g_filename_from_uri(p, NULL, NULL)) != NULL) {
 					if (!is_file_exist(file)) {
 						g_free(file);
@@ -1929,7 +1962,9 @@ static void parse_cmd_opt(int argc, char *argv[])
 				} else if (file == NULL) {
 					file = g_strdup(p);
 				}
-				g_ptr_array_add(cmd.attach_files, file);
+				ainfo = g_new0(AttachInfo, 1);
+				ainfo->file = file;
+				cmd.attach_files = g_list_append(cmd.attach_files, ainfo);
 				i++;
 				p = (i+1 < argc)?argv[i+1]:NULL;
 			}
@@ -1984,6 +2019,10 @@ static void parse_cmd_opt(int argc, char *argv[])
 			cmd.online_mode = ONLINE_MODE_ONLINE;
 		} else if (!strncmp(argv[i], "--offline", 9)) {
 			cmd.online_mode = ONLINE_MODE_OFFLINE;
+		} else if (!strncmp(argv[i], "--statistics", 12)) {
+			cmd.statistics = TRUE;
+		} else if (!strncmp(argv[i], "--reset-statistics", 18)) {
+			cmd.reset_statistics = TRUE;
 		} else if (!strncmp(argv[i], "--help", 6) ||
 			   !strncmp(argv[i], "-h", 2)) {
 			gchar *base = g_path_get_basename(argv[0]);
@@ -2012,6 +2051,8 @@ static void parse_cmd_opt(int argc, char *argv[])
  			g_print("%s\n", _("  --status [folder]...   show the total number of messages"));
  			g_print("%s\n", _("  --status-full [folder]...\n"
  			                  "                         show the status of each folder"));
+ 			g_print("%s\n", _("  --statistics           show session statistics"));
+ 			g_print("%s\n", _("  --reset-statistics     reset session statistics"));
 			g_print("%s\n", _("  --select folder[/msg]  jumps to the specified folder/message\n" 
 			                  "                         folder is a folder id like 'folder/sub_folder'"));
 			g_print("%s\n", _("  --online               switch to online mode"));
@@ -2249,6 +2290,7 @@ static gchar *get_crashfile_name(void)
 static gint prohibit_duplicate_launch(void)
 {
 	gint uxsock;
+	GList *curr;
 #ifdef G_OS_UNIX
 	gchar *path;
 
@@ -2291,7 +2333,6 @@ static gint prohibit_duplicate_launch(void)
 		fd_write_all(uxsock, "receive\n", 8);
 	} else if (cmd.compose && cmd.attach_files) {
 		gchar *str, *compose_str;
-		gint i;
 
 		if (cmd.compose_mailto) {
 			compose_str = g_strdup_printf("compose_attach %s\n",
@@ -2303,8 +2344,8 @@ static gint prohibit_duplicate_launch(void)
 		fd_write_all(uxsock, compose_str, strlen(compose_str));
 		g_free(compose_str);
 
-		for (i = 0; i < cmd.attach_files->len; i++) {
-			str = g_ptr_array_index(cmd.attach_files, i);
+		for (curr = cmd.attach_files; curr != NULL ; curr = curr->next) {
+			str = (gchar *) ((AttachInfo *)curr->data)->file;
 			fd_write_all(uxsock, str, strlen(str));
 			fd_write_all(uxsock, "\n", 1);
 		}
@@ -2357,6 +2398,16 @@ static gint prohibit_duplicate_launch(void)
  		}
 	} else if (cmd.exit) {
 		fd_write_all(uxsock, "exit\n", 5);
+	} else if (cmd.statistics) {
+		gchar buf[BUFSIZ];
+		fd_write(uxsock, "statistics\n", 11);
+ 		for (;;) {
+ 			fd_gets(uxsock, buf, sizeof(buf));
+ 			if (!strncmp(buf, ".\n", 2)) break;
+ 			fputs(buf, stdout);
+ 		}
+	} else if (cmd.reset_statistics) {
+		fd_write(uxsock, "reset_statistics\n", 17);
 	} else if (cmd.target) {
 		gchar *str = g_strdup_printf("select %s\n", cmd.target);
 		fd_write_all(uxsock, str, strlen(str));
@@ -2468,20 +2519,30 @@ static void lock_socket_input_cb(gpointer data,
 	} else if (!strncmp(buf, "receive", 7)) {
 		inc_mail(mainwin, prefs_common.newmail_notify_manu);
 	} else if (!strncmp(buf, "compose_attach", 14)) {
-		GPtrArray *files;
+		GList *files = NULL, *curr;
+		AttachInfo *ainfo;
 		gchar *mailto;
 
 		mailto = g_strdup(buf + strlen("compose_attach") + 1);
-		files = g_ptr_array_new();
 		while (fd_gets(sock, buf, sizeof(buf)) > 0) {
 			strretchomp(buf);
 			if (!strcmp2(buf, "."))
 				break;
-			g_ptr_array_add(files, g_strdup(buf));
+				
+			ainfo = g_new0(AttachInfo, 1);
+			ainfo->file = g_strdup(buf);
+			files = g_list_append(files, ainfo);
 		}
 		open_compose_new(mailto, files);
-		ptr_array_free_strings(files);
-		g_ptr_array_free(files, TRUE);
+		
+		curr = g_list_first(files);
+		while (curr != NULL) {
+			ainfo = (AttachInfo *)curr->data;
+			g_free(ainfo->file);
+			g_free(ainfo);
+			curr = curr->next;
+		}
+		g_list_free(files);
 		g_free(mailto);
 	} else if (!strncmp(buf, "compose", 7)) {
 		open_compose_new(buf + strlen("compose") + 1, NULL);
@@ -2506,6 +2567,48 @@ static void lock_socket_input_cb(gpointer data,
  		fd_write_all(sock, ".\n", 2);
  		g_free(status);
  		if (folders) g_ptr_array_free(folders, TRUE);
+	} else if (!strncmp(buf, "statistics", 10)) {
+		gchar tmp[BUFSIZ];
+
+		g_snprintf(tmp, sizeof(tmp), _("Session statistics\n"));
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Started: %s\n"),
+				ctime(&session_stats.time_started));
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Incoming traffic\n"));
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Received messages: %d\n"),
+				session_stats.received);
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+ 		fd_write_all(sock, "\n", 1);
+
+		g_snprintf(tmp, sizeof(tmp), _("Outgoing traffic\n"));
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("New/redirected messages: %d\n"),
+				session_stats.sent);
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Replied messages: %d\n"),
+				session_stats.replied);
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Forwarded messages: %d\n"),
+				session_stats.forwarded);
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+		g_snprintf(tmp, sizeof(tmp), _("Total outgoing messages: %d\n"),
+				(session_stats.sent + session_stats.replied +
+				 session_stats.forwarded));
+ 		fd_write_all(sock, tmp, strlen(tmp));
+
+ 		fd_write_all(sock, ".\n", 2);
+	} else if (!strncmp(buf, "reset_statistics", 16)) {
+		reset_statistics();
 	} else if (!strncmp(buf, "select ", 7)) {
 		const gchar *target = buf+7;
 		mainwindow_jump_to(target, TRUE);
@@ -2544,7 +2647,7 @@ static void lock_socket_input_cb(gpointer data,
 		if (folder_name)
 			folderItem = folder_find_item_from_identifier(folder_name);
 		if (folder_name && folderItem == NULL) {
-			debug_print("Unknow folder item : '%s', searching folder\n",folder_name);
+			debug_print("Unknown folder item : '%s', searching folder\n",folder_name);
 			Folder* folder = folder_find_from_path(folder_name);
 			if (folder != NULL)
 				folderItem = FOLDER_ITEM(folder->node->data);
@@ -2585,7 +2688,7 @@ static void lock_socket_input_cb(gpointer data,
 
 }
 
-static void open_compose_new(const gchar *address, GPtrArray *attach_files)
+static void open_compose_new(const gchar *address, GList *attach_files)
 {
 	gchar *addr = NULL;
 
