@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2011 by the Claws Mail Team and Hiroyuki Yamamoto
+ * Copyright (C) 2002-2012 by the Claws Mail Team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -925,7 +925,7 @@ gboolean matcherprop_match(MatcherProp *prop,
 
 		t = time(NULL);
 		age = ((t - info->date_t) / (60 * 60 * 24));
-		ret = (age > prop->value);
+		ret = (age >= prop->value);
 
 		/* debug output */
 		if (debug_filtering_session
