@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,10 +89,6 @@ static gboolean mimeview_write_part		(const gchar	*filename,
 
 static void mimeview_selected		(GtkTreeSelection	*selection,
 					 MimeView	*mimeview);
-static void mimeview_start_drag 	(GtkWidget	*widget,
-					 gint		 button,
-					 GdkEvent	*event,
-					 MimeView	*mimeview);
 static gint mimeview_button_pressed	(GtkWidget	*widget,
 					 GdkEventButton	*event,
 					 MimeView	*mimeview);
@@ -121,6 +117,8 @@ static void mimeview_open_part_with	(MimeView	*mimeview,
 					 MimeInfo	*partinfo,
 					 gboolean	 automatic);
 #endif
+static void mimeview_send_to		(MimeView	*mimeview,
+					 MimeInfo	*partinfo);
 static void mimeview_select_next_part	(MimeView	*mimeview);
 static void mimeview_select_prev_part	(MimeView	*mimeview);
 static void mimeview_view_file		(const gchar	*filename,
@@ -171,6 +169,12 @@ static void mimeview_open_with_cb(GtkAction *action, gpointer data)
 }
 #endif
 
+static void mimeview_send_to_cb(GtkAction *action, gpointer data)
+{
+	MimeView *mimeview = (MimeView *)data;	
+	mimeview_send_to(mimeview, mimeview_get_part_to_use(mimeview));
+}
+
 static void mimeview_display_as_text_cb(GtkAction *action, gpointer data)
 {
 	mimeview_display_as_text((MimeView *)data);
@@ -202,6 +206,7 @@ static GtkActionEntry mimeview_menu_actions[] = {
 #if (!defined MAEMO && !defined G_OS_WIN32)
 	{ "MimeView/OpenWith", NULL, N_("Open _with (o)..."), NULL, "Open MIME part with...", G_CALLBACK(mimeview_open_with_cb) },
 #endif
+	{ "MimeView/SendTo", NULL, N_("Send to..."), NULL, "Send to", G_CALLBACK(mimeview_send_to_cb) },
 	{ "MimeView/DisplayAsText", NULL, N_("_Display as text (t)"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
 	{ "MimeView/SaveAs", NULL, N_("_Save as (y)..."), NULL, "Save as", G_CALLBACK(mimeview_save_as_cb) },
 	{ "MimeView/SaveAll", NULL, N_("Save _all..."), NULL, "Save all parts", G_CALLBACK(mimeview_save_all_cb) },
@@ -307,7 +312,9 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	column = gtk_tree_view_get_column(GTK_TREE_VIEW(ctree), cols-1);
 							   
 	renderer = gtk_cell_renderer_text_new();
+#if(GTK_CHECK_VERSION(2,18,0))
 	gtk_cell_renderer_set_alignment(renderer, 1, 0.5);
+#endif
 	cols = gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(ctree),
 					-1, titles[COL_SIZE], renderer,
 					"text", COL_SIZE, NULL);
@@ -326,16 +333,16 @@ MimeView *mimeview_create(MainWindow *mainwin)
 
 	gtk_widget_show(ctree);
 	gtk_container_add(GTK_CONTAINER(scrolledwin), ctree);
+	gtk_drag_source_set(ctree, GDK_BUTTON1_MASK|GDK_BUTTON3_MASK, 
+			    mimeview_mime_types, 1, GDK_ACTION_COPY);
 
 	g_signal_connect(G_OBJECT(selection), "changed",
 			 G_CALLBACK(mimeview_selected), mimeview);
-	g_signal_connect(G_OBJECT(ctree), "button-release-event",
+	g_signal_connect(G_OBJECT(ctree), "button_release_event",
 			 G_CALLBACK(mimeview_button_pressed), mimeview);
-	g_signal_connect(G_OBJECT(ctree), "key-press-event",
+	g_signal_connect(G_OBJECT(ctree), "key_press_event",
 			 G_CALLBACK(mimeview_key_pressed), mimeview);
-	g_signal_connect(G_OBJECT (ctree),"drag-begin",
-			 G_CALLBACK (mimeview_start_drag), mimeview);
-	g_signal_connect(G_OBJECT(ctree), "drag-data-get",
+	g_signal_connect(G_OBJECT(ctree), "drag_data_get",
 			 G_CALLBACK(mimeview_drag_data_get), mimeview);
 
 	mime_notebook = gtk_notebook_new();
@@ -405,6 +412,9 @@ MimeView *mimeview_create(MainWindow *mainwin)
 			"/Menus/MimeView/", "OpenWith", "MimeView/OpenWith",
 			GTK_UI_MANAGER_MENUITEM);
 #endif
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SendTo", "MimeView/SendTo",
+			GTK_UI_MANAGER_MENUITEM);
 	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
 			"/Menus/MimeView/", "DisplayAsText", "MimeView/DisplayAsText",
 			GTK_UI_MANAGER_MENUITEM);
@@ -620,10 +630,15 @@ static gboolean mimeview_tree_next(GtkTreeModel *model, GtkTreePath *path)
 	has_parent = gtk_tree_model_iter_parent(model, &parent, &iter);
 	
 	if (!gtk_tree_model_iter_next(model, &iter)) {
-		if (has_parent && gtk_tree_model_iter_next(model, &parent)) {
+		while (has_parent) {
+			GtkTreeIter saved_parent = parent;
 			gtk_tree_path_up(path);
-			gtk_tree_path_next(path);
-			return TRUE;
+			if (gtk_tree_model_iter_next(model, &parent)) {
+				gtk_tree_path_next(path);
+				return TRUE;
+			} else {
+				has_parent = gtk_tree_model_iter_parent(model, &parent, &saved_parent);
+			}
 		}
 		
 	} else {
@@ -1435,24 +1450,6 @@ static void mimeview_selected(GtkTreeSelection *selection, MimeView *mimeview)
 	}
 }
 
-static void mimeview_start_drag(GtkWidget *widget, gint button,
-				GdkEvent *event, MimeView *mimeview)
-{
-	GdkDragContext *context;
-	MimeInfo *partinfo;
-
-	cm_return_if_fail(mimeview != NULL);
-
-	partinfo = mimeview_get_selected_part(mimeview);
-	if (partinfo == NULL || 
-	    partinfo->disposition == DISPOSITIONTYPE_INLINE)
-		return;
-
-	context = gtk_drag_begin(widget, mimeview->target_list,
-				 GDK_ACTION_COPY, button, event);
-	gtk_drag_set_icon_default(context);
-}
-
 static gint mimeview_button_pressed(GtkWidget *widget, GdkEventButton *event,
 				    MimeView *mimeview)
 {
@@ -2196,6 +2193,44 @@ out:
 }
 #endif
 
+static void mimeview_send_to(MimeView *mimeview, MimeInfo *partinfo)
+{
+	GList *attach_file = NULL;
+	AttachInfo *ainfo = NULL;
+	gchar *filename;
+	gint err;
+
+	if (!mimeview->opened) return;
+	if (!mimeview->file) return;
+
+	cm_return_if_fail(partinfo != NULL);
+
+	filename = procmime_get_tmp_file_name(partinfo);
+
+	if (!(err = procmime_get_part(filename, partinfo))) {
+		ainfo = g_new0(AttachInfo, 1);
+		ainfo->file = filename;
+		ainfo->name = g_strdup(get_part_name(partinfo));
+		ainfo->content_type = procmime_get_content_type_str(
+					partinfo->type, partinfo->subtype);
+		ainfo->charset = g_strdup(procmime_mimeinfo_get_parameter(
+					partinfo, "charset"));
+		attach_file = g_list_append(attach_file, ainfo);
+		
+		compose_new(NULL, NULL, attach_file);
+		
+		g_free(ainfo->name);
+		g_free(ainfo->content_type);
+		g_free(ainfo->charset);
+		g_free(ainfo);
+		g_list_free(attach_file);
+	} else
+		alertpanel_error
+			(_("Couldn't save the part of multipart message: %s"), 
+				strerror(-err));
+	g_free(filename);
+}
+
 static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			       const gchar *cmd, MimeView *mimeview)
 {
