@@ -1,6 +1,6 @@
 /* 
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 2002-2012 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,9 @@ struct _NoticeView
 	void		(*press2) (NoticeView *, gpointer user_data);
 	gboolean	 icon_clickable;
 	GtkWidget 	*evtbox;
-	GtkTooltips	*tooltips;
+#if !GTK_CHECK_VERSION(2,12,0)
+	GtkTooltips *tooltips;
+#endif
 };
 
 NoticeView	*noticeview_create	(MainWindow 	*mainwin);
@@ -63,11 +65,11 @@ void		 noticeview_hide	(NoticeView	*noticeview);
 
 void		 noticeview_set_button_press_callback
 					(NoticeView	*noticeview,
-					 GtkSignalFunc   callback,
+					 void 		(*callback)(void),
 					 gpointer	*user_data);
 void		 noticeview_set_2ndbutton_press_callback
 					(NoticeView	*noticeview,
-					 GtkSignalFunc   callback,
+					 void 		(*callback)(void),
 					 gpointer	*user_data);
 void		 noticeview_set_icon_clickable
 					(NoticeView	*noticeview,
