@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,7 +59,9 @@
 #include "stock_pixmap.h"
 #include "prefswindow.h"
 #include "colorlabel.h"
-#include "addrcustomattr.h"
+#ifndef USE_NEW_ADDRBOOK
+	#include "addrcustomattr.h"
+#endif
 
 enum {
 	DATEFMT_FMT,
@@ -1165,6 +1167,16 @@ static PrefParam param[] = {
 	{"flush_metadata", "TRUE", &prefs_common.flush_metadata, P_BOOL,
 	 NULL, NULL, NULL},
 
+	{"nav_history_length", "50", &prefs_common.nav_history_length, P_INT,
+	 NULL, NULL, NULL},
+
+	{"diff_added_color", "#008b8b", &prefs_common.diff_added_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"diff_deleted_color", "#6a5acd", &prefs_common.diff_deleted_color, P_COLOR,
+	 NULL, NULL, NULL},
+	{"diff_hunk_color", "#a52a2a", &prefs_common.diff_hunk_color, P_COLOR,
+	 NULL, NULL, NULL},
+
 	{NULL, NULL, NULL, P_OTHER, NULL, NULL, NULL}
 };
 
@@ -1258,9 +1270,9 @@ void prefs_common_read_config(void)
 		prefs_common_read_history(MESSAGE_SEARCH_HISTORY);
 	prefs_common.compose_save_to_history =
 		prefs_common_read_history(COMPOSE_SAVE_TO_HISTORY);
-
+#ifndef USE_NEW_ADDRBOOK
 	prefs_common.addressbook_custom_attributes = addressbook_update_custom_attr_from_prefs();
-
+#endif
 	colorlabel_update_colortable_from_prefs();
 }
 
@@ -1357,9 +1369,11 @@ void prefs_common_write_config(void)
 	prefs_common_save_history(COMPOSE_SAVE_TO_HISTORY, 
 		prefs_common.compose_save_to_history);
 
-	prefs_common_save_history_to_dir(ADDRBOOK_DIR,
+#ifndef USE_NEW_ADDRBOOK
+		prefs_common_save_history_to_dir(ADDRBOOK_DIR,
 		ADDRESSBOOK_CUSTOM_ATTRIBUTES, 
 		prefs_common.addressbook_custom_attributes);
+#endif
 }
 
 /* make a copy of string 'in' into buffer 'out'. un-escape \ sequences.
