@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,6 +95,13 @@ typedef enum
 	OPENMSG_WHEN_VIEW_VISIBLE
 } ShowMsgPolicy;
 
+typedef enum
+{
+	SHOW_NAME,
+	SHOW_ADDR,
+	SHOW_BOTH
+} SummaryFromShow;
+
 struct _PrefsCommon
 {
 #ifdef MAEMO
@@ -215,11 +222,11 @@ struct _PrefsCommon
 	gboolean swap_from;
 	gboolean use_addr_book;
 	gchar *date_format;
+	gboolean *msgview_date_format;
 
 	gboolean use_stripes_everywhere;
 	gboolean use_stripes_in_summaries; /* overrides if use_stripes_everywhere is set to TRUE */
 	gint stripes_color_offset;
-	gboolean enable_dotted_lines;
 	gboolean enable_hscrollbar;
 	gboolean bold_unread;
 	gboolean enable_thread;
@@ -285,11 +292,14 @@ struct _PrefsCommon
 	gint msgwin_width;
 	gint msgwin_height;
 
+	gint mimeview_tree_height;
+	
 	gint sourcewin_width;
 	gint sourcewin_height;
 
 	gint compose_width;
 	gint compose_height;
+	gint compose_notebook_height;
 	gint compose_x;
 	gint compose_y;
 
@@ -320,6 +330,7 @@ struct _PrefsCommon
 	gboolean scroll_halfpage;
 	gboolean hide_quoted;
 	gboolean respect_flowed_format;
+	gboolean show_all_headers;
 
 	gboolean show_other_header;
 	GSList *disphdr_list;
@@ -333,6 +344,7 @@ struct _PrefsCommon
 	gchar *attach_load_dir;
 
 	GList *mime_open_cmd_history;
+	gboolean show_inline_attachments;
 
 	/* Addressbook */
 	gboolean addressbook_use_editaddress_dialog;
@@ -355,6 +367,7 @@ struct _PrefsCommon
 	EntryAction summary_select_prio[SUMMARY_OPEN_ACTIONS-1];
 
 	NextUnreadMsgDialogShow next_unread_msg_dialog;
+	SummaryFromShow summary_from_show;
 	gboolean add_address_by_click;
 	gchar *pixmap_theme_path;
 	int hover_timeout; /* msecs mouse hover timeout */
@@ -506,6 +519,11 @@ struct _PrefsCommon
 	gboolean inherit_folder_props;
 	gboolean flush_metadata;
 
+	gint nav_history_length;
+
+	gulong diff_added_color;
+	gulong diff_deleted_color;
+	gulong diff_hunk_color;
 };
 
 extern PrefsCommon prefs_common;
