@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,7 +55,9 @@
 #include "colorlabel.h"
 #include "tags.h"
 
+#ifndef USE_NEW_ADDRBOOK
 static void prefs_matcher_addressbook_select(void);
+#endif
 static void prefs_matcher_test_info(GtkWidget *widget, GtkWidget *parent);
 
 enum {
@@ -528,10 +530,7 @@ static void prefs_matcher_create(void)
 
 	GtkWidget *test_btn;
 	GtkWidget *addressbook_select_btn;
-
-#if !GTK_CHECK_VERSION(3, 0, 0)
 	GtkWidget *color_optmenu;
-#endif
 
 	static GdkGeometry geometry;
 	GtkSizeGroup *size_group;
@@ -657,10 +656,13 @@ static void prefs_matcher_create(void)
 
 	addressbook_select_btn = gtk_button_new_with_label(_("Select ..."));
 	gtk_box_pack_start(GTK_BOX(upper_hbox), addressbook_select_btn, FALSE, FALSE, 0);
+#ifndef USE_NEW_ADDRBOOK
 	g_signal_connect(G_OBJECT (addressbook_select_btn), "clicked",
 			 G_CALLBACK(prefs_matcher_addressbook_select),
 			 NULL);
-
+#else
+	gtk_widget_set_sensitive(GTK_WIDGET(addressbook_select_btn), FALSE);
+#endif
 	match_label = gtk_label_new("");
 	gtk_misc_set_alignment(GTK_MISC(match_label), 1, 0.5);
 	gtk_table_attach(GTK_TABLE(table), match_label, 0, 1, 1, 2,
@@ -833,10 +835,10 @@ static void prefs_matcher_create(void)
 #endif
 	matcher.bool_op_combo = bool_op_combo;
 	matcher.test_btn = test_btn;
+#ifndef USE_NEW_ADDRBOOK
 	matcher.addressbook_select_btn = addressbook_select_btn;
-#if !GTK_CHECK_VERSION(3, 0, 0)
-	matcher.color_optmenu = color_optmenu;
 #endif
+	matcher.color_optmenu = color_optmenu;
 	matcher.match_label = match_label;
 	matcher.criteria_label2 = criteria_label2;
 	matcher.headers_combo = headers_combo;
@@ -2145,6 +2147,7 @@ static void prefs_matcher_test_info(GtkWidget *widget, GtkWidget *parent)
 	description_window_create(&test_desc_win);
 }
 
+#ifndef USE_NEW_ADDRBOOK
 static void prefs_matcher_addressbook_select(void)
 {
 	const gchar *folderpath = NULL;
@@ -2157,7 +2160,7 @@ static void prefs_matcher_addressbook_select(void)
 		g_free(new_path);
 	} 
 }
-
+#endif
 
 /*
  * list view
