@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1701,15 +1701,15 @@ static void parse_parameters(const gchar *parameters, GHashTable *table)
 			tmp[0] = '\0';
 
 			if ((tmp[1] == '0') && (tmp[2] == '\0') && 
-			    (g_slist_find_custom(concatlist, down_attr, g_str_equal) == NULL))
+			    (g_slist_find_custom(concatlist, down_attr, g_strcmp0) == NULL))
 				concatlist = g_slist_prepend(concatlist, g_strdup(tmpattr));
 
-			if (convert && (g_slist_find_custom(convlist, down_attr, g_str_equal) == NULL))
+			if (convert && (g_slist_find_custom(convlist, down_attr, g_strcmp0) == NULL))
 				convlist = g_slist_prepend(convlist, g_strdup(tmpattr));
 
 			g_free(tmpattr);
 		} else if (convert) {
-			if (g_slist_find_custom(convlist, down_attr, g_str_equal) == NULL)
+			if (g_slist_find_custom(convlist, down_attr, g_strcmp0) == NULL)
 				convlist = g_slist_prepend(convlist, g_strdup(down_attr));
 		}
 
