@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,8 @@
 #include "timing.h"
 #include "inc.h"
 
+extern SessionStats session_stats;
+
 static gint procmsg_send_message_queue_full(const gchar *file, gboolean keep_session, gchar **errstr,
 					    FolderItem *queue, gint msgnum, gboolean *queued_removed);
 static void procmsg_update_unread_children	(MsgInfo 	*info,
@@ -756,6 +758,52 @@ static PrefsAccount *procmsg_get_account_from_file(const gchar *file)
 	return mailac;
 }
 
+gchar *procmsg_msginfo_get_identifier(MsgInfo *msginfo)
+{
+	gchar *folder_id;
+	const gchar *msgid;
+	gchar *id;
+
+	cm_return_val_if_fail(msginfo != NULL, NULL);
+	folder_id = folder_item_get_identifier(msginfo->folder);
+	msgid = msginfo->msgid;
+
+	id = g_strconcat(folder_id, G_DIR_SEPARATOR_S, msgid, NULL);
+
+	g_free(folder_id);
+
+	return id;
+}
+
+MsgInfo *procmsg_get_msginfo_from_identifier(const gchar *id)
+{
+	gchar *folder_id = g_strdup(id);
+	gchar *separator = strrchr(folder_id, G_DIR_SEPARATOR);
+	const gchar *msgid;
+	FolderItem *item;
+	MsgInfo *msginfo;
+
+	if (separator == NULL) {
+		g_free(folder_id);
+		return NULL;
+	}
+
+	*separator = '\0';
+	msgid = separator + 1;
+
+	item = folder_find_item_from_identifier(folder_id);
+
+	if (item == NULL) {
+		g_free(folder_id);
+		return NULL;
+	}
+
+	msginfo = folder_item_get_msginfo_by_msgid(item, msgid);
+	g_free(folder_id);
+
+	return msginfo;
+}
+
 static GSList *procmsg_list_sort_by_account(FolderItem *queue, GSList *list)
 {
 	GSList *result = NULL;
@@ -1147,7 +1195,8 @@ void procmsg_print_message(MsgInfo *msginfo, const gchar *cmdline)
 	g_free(prtmp);
 
 	g_strchomp(buf);
-	if (buf[strlen(buf) - 1] != '&') strncat(buf, "&", sizeof(buf));
+	if (buf[strlen(buf) - 1] != '&')
+		strncat(buf, "&", sizeof(buf) - strlen(buf) - 1);
 	if (system(buf) == -1)
 		g_warning("system(%s) failed.", buf);
 }
@@ -1714,6 +1763,19 @@ send_mail:
 
 	fclose(fp);
 
+	/* update session statistics */
+	if (mailval == 0 && newsval == 0) {
+		/* update session stats */
+		if (replymessageid)
+			session_stats.replied++;
+		else if (fwdmessageid)
+			session_stats.forwarded++;
+		else
+			session_stats.sent++;
+fprintf(stdout, "++ STATS ++ SENT %d %d %d\n", session_stats.sent, session_stats.replied, session_stats.forwarded);
+fflush(stdout);
+	}
+
 	/* save message to outbox */
 	if (mailval == 0 && newsval == 0 && savecopyfolder) {
 		FolderItem *outbox;
@@ -1784,16 +1846,15 @@ send_mail:
 			}
 			
 			if (msginfo != NULL) {
-				MsgPermFlags to_unset = 0;
-
-				if (prefs_common.mark_as_read_on_new_window)
-					to_unset = (MSG_NEW|MSG_UNREAD);
-
 				if (replymessageid != NULL) {
-					procmsg_msginfo_unset_flags(msginfo, to_unset|MSG_FORWARDED, 0);
+					MsgPermFlags to_unset = 0;
+
+					if (prefs_common.mark_as_read_on_new_window)
+						to_unset = (MSG_NEW|MSG_UNREAD);
+
+					procmsg_msginfo_unset_flags(msginfo, to_unset, 0);
 					procmsg_msginfo_set_flags(msginfo, MSG_REPLIED, 0);
 				}  else {
-					procmsg_msginfo_unset_flags(msginfo, MSG_REPLIED, 0);
 					procmsg_msginfo_set_flags(msginfo, MSG_FORWARDED, 0);
 				}
 				procmsg_msginfo_free(msginfo);
