@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -330,6 +330,8 @@ void	procmsg_empty_all_trash		(void);
 gint	procmsg_send_queue		(FolderItem	*queue,
 					 gboolean	 save_msgs,
 					 gchar		**errstr);
+gboolean procmsg_queue_lock		(gchar		**errstr);
+void     procmsg_queue_unlock		(void);
 gboolean procmsg_queue_is_empty	(FolderItem *queue);
 void	procmsg_print_message		(MsgInfo	*msginfo,
 					 const gchar	*cmdline);
@@ -344,6 +346,12 @@ MsgInfo *procmsg_msginfo_get_full_info_from_file
 void	 procmsg_msginfo_free		(MsgInfo	*msginfo);
 guint	 procmsg_msginfo_memusage	(MsgInfo	*msginfo);
 
+gint procmsg_send_message_queue_with_lock(const gchar *file,
+					  gchar **errstr,
+					  FolderItem *queue,
+					  gint msgnum,
+					  gboolean *queued_removed);
+
 gint procmsg_send_message_queue		(const gchar *file,
 					 gchar **errstr,
 					 FolderItem *queue, 
@@ -392,4 +400,6 @@ gchar *procmsg_msginfo_get_tags_str(MsgInfo *msginfo);
 void procmsg_msginfo_update_tags(MsgInfo *msginfo, gboolean set, gint id);
 void procmsg_msginfo_clear_tags(MsgInfo *msginfo);
 void procmsg_msginfo_commit_tags(GSList *msglist);
+MsgInfo *procmsg_get_msginfo_from_identifier(const gchar *id);
+gchar *procmsg_msginfo_get_identifier(MsgInfo *msginfo);
 #endif /* __PROCMSG_H__ */
