@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -55,7 +55,13 @@
 #include "html.h"
 #include "enriched.h"
 #include "compose.h"
-#include "addressbook.h"
+#ifndef USE_NEW_ADDRBOOK
+	#include "addressbook.h"
+	#include "addrindex.h"
+#else
+	#include "addressbook-dbus.h"
+	#include "addressadd.h"
+#endif
 #include "displayheader.h"
 #include "account.h"
 #include "mimeview.h"
@@ -67,7 +73,6 @@
 #include "inputdialog.h"
 #include "timing.h"
 #include "tags.h"
-#include "addrindex.h"
 
 static GdkColor quote_colors[3] = {
 	{(gulong)0, (gushort)0, (gushort)0, (gushort)0},
@@ -101,6 +106,27 @@ static GdkColor emphasis_color = {
 	(gushort)0
 };
 
+static GdkColor diff_added_color = {
+	(gulong)0,
+	(gushort)0,
+	(gushort)0,
+	(gushort)0
+};
+
+static GdkColor diff_deleted_color = {
+	(gulong)0,
+	(gushort)0,
+	(gushort)0,
+	(gushort)0
+};
+
+static GdkColor diff_hunk_color = {
+	(gulong)0,
+	(gushort)0,
+	(gushort)0,
+	(gushort)0
+};
+
 static GdkCursor *hand_cursor = NULL;
 static GdkCursor *text_cursor = NULL;
 static GdkCursor *watch_cursor= NULL;
@@ -483,6 +509,24 @@ static void textview_create_tags(GtkTextView *text, TextView *textview)
 	gtk_text_buffer_create_tag(buffer, "link-hover",
 			"underline", PANGO_UNDERLINE_SINGLE,
 			NULL);
+	gtk_text_buffer_create_tag(buffer, "diff-add",
+			"foreground-gdk", &diff_added_color,
+			NULL);
+	gtk_text_buffer_create_tag(buffer, "diff-del",
+			"foreground-gdk", &diff_deleted_color,
+			NULL);
+	gtk_text_buffer_create_tag(buffer, "diff-add-file",
+			"foreground-gdk", &diff_added_color,
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL);
+	gtk_text_buffer_create_tag(buffer, "diff-del-file",
+			"foreground-gdk", &diff_deleted_color,
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL);
+	gtk_text_buffer_create_tag(buffer, "diff-hunk",
+			"foreground-gdk", &diff_hunk_color,
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL);
 	g_signal_connect(G_OBJECT(qtag), "event",
                          G_CALLBACK(textview_uri_button_pressed), textview);
 	g_signal_connect(G_OBJECT(tag), "event",
@@ -522,8 +566,9 @@ static void textview_update_message_colors(TextView *textview)
 	GtkTextTag *tag = NULL;
 
 	quote_bgcolors[0] = quote_bgcolors[1] = quote_bgcolors[2] = black;
-	quote_colors[0] = quote_colors[1] = quote_colors[2] = 
-		uri_color = emphasis_color = signature_color = black;
+	quote_colors[0] = quote_colors[1] = quote_colors[2] = black;
+	uri_color = emphasis_color = signature_color = diff_added_color =
+		diff_deleted_color = diff_hunk_color = black;
 
 	if (prefs_common.enable_color) {
 		/* grab the quote colors, converting from an int to a GdkColor */
@@ -539,6 +584,12 @@ static void textview_update_message_colors(TextView *textview)
 					       &signature_color);
 		gtkut_convert_int_to_gdk_color(prefs_common.emphasis_col,
 					       &emphasis_color);
+		gtkut_convert_int_to_gdk_color(prefs_common.diff_added_color,
+					       &diff_added_color);
+		gtkut_convert_int_to_gdk_color(prefs_common.diff_deleted_color,
+					       &diff_deleted_color);
+		gtkut_convert_int_to_gdk_color(prefs_common.diff_hunk_color,
+					       &diff_hunk_color);
 	}
 	if (prefs_common.enable_color && prefs_common.enable_bgcolor) {
 		gtkut_convert_int_to_gdk_color(prefs_common.quote_level1_bgcol,
@@ -560,6 +611,11 @@ static void textview_update_message_colors(TextView *textview)
 	CHANGE_TAG_COLOR("signature", &signature_color, NULL);
 	CHANGE_TAG_COLOR("link", &uri_color, NULL);
 	CHANGE_TAG_COLOR("link-hover", &uri_color, NULL);
+	CHANGE_TAG_COLOR("diff-add", &diff_added_color, NULL);
+	CHANGE_TAG_COLOR("diff-del", &diff_deleted_color, NULL);
+	CHANGE_TAG_COLOR("diff-add-file", &diff_added_color, NULL);
+	CHANGE_TAG_COLOR("diff-del-file", &diff_deleted_color, NULL);
+	CHANGE_TAG_COLOR("diff-hunk", &diff_hunk_color, NULL);
 }
 #undef CHANGE_TAG_COLOR
 
@@ -862,6 +918,24 @@ void textview_show_error(TextView *textview)
 	textview_show_icon(textview, GTK_STOCK_DIALOG_ERROR);
 }
 
+void textview_show_info(TextView *textview, const gchar *info_str)
+{
+	GtkTextView *text;
+	GtkTextBuffer *buffer;
+	GtkTextIter iter;
+
+	textview_set_font(textview, NULL);
+	textview_clear(textview);
+
+	text = GTK_TEXT_VIEW(textview->text);
+	buffer = gtk_text_view_get_buffer(text);
+	gtk_text_buffer_get_start_iter(buffer, &iter);
+
+	TEXTVIEW_INSERT(info_str);
+	textview_show_icon(textview, GTK_STOCK_DIALOG_INFO);
+	textview_cursor_normal(textview);
+}
+
 void textview_show_mime_part(TextView *textview, MimeInfo *partinfo)
 {
 	GtkTextView *text;
@@ -968,6 +1042,7 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 	procmime_force_encoding(textview->messageview->forced_encoding);
 	
 	textview->is_in_signature = FALSE;
+	textview->is_diff = FALSE;
 
 	procmime_decode_content(mimeinfo);
 
@@ -1057,6 +1132,10 @@ static void textview_write_body(TextView *textview, MimeInfo *mimeinfo)
 #endif
 	} else {
 textview_default:
+		if (!g_ascii_strcasecmp(mimeinfo->subtype, "x-patch")
+				|| !g_ascii_strcasecmp(mimeinfo->subtype, "x-diff"))
+			textview->is_diff = TRUE;
+
 		if (mimeinfo->content == MIMECONTENT_MEM)
 			tmpfp = str_open_as_stream(mimeinfo->data.mem);
 		else
@@ -1498,10 +1577,25 @@ static void textview_write_line(TextView *textview, const gchar *str,
 		fg_color = quote_tag_str;
 	}
 
-	if (prefs_common.enable_color && 
-	    (strcmp(buf,"-- \n") == 0 || strcmp(buf, "- -- \n") == 0 || textview->is_in_signature)) {
-		fg_color = "signature";
-		textview->is_in_signature = TRUE;
+	if (prefs_common.enable_color) {
+		if (textview->is_diff) {
+			if (strncmp(buf, "+++ ", 4) == 0)
+				fg_color = "diff-add-file";
+			else if (buf[0] == '+')
+				fg_color = "diff-add";
+			else if (strncmp(buf, "--- ", 4) == 0)
+				fg_color = "diff-del-file";
+			else if (buf[0] == '-')
+				fg_color = "diff-del";
+			else if (strncmp(buf, "@@ ", 3) == 0 &&
+					strcmp(buf+strlen(buf)-4, " @@\n") == 0)
+				fg_color = "diff-hunk";
+		} else if (strcmp(buf,"-- \n") == 0
+				|| strcmp(buf, "- -- \n") == 0
+				|| textview->is_in_signature) {
+			fg_color = "signature";
+			textview->is_in_signature = TRUE;
+		}
 	}
 
 	if (real_quotelevel > -1 && do_quote_folding) {
@@ -1920,6 +2014,7 @@ void textview_show_icon(TextView *textview, const gchar *stock_id)
 #if HAVE_LIBCOMPFACE
 static void textview_show_xface(TextView *textview)
 {
+	GtkAllocation allocation;
 	MsgInfo *msginfo = textview->messageview->msginfo;
 	GtkTextView *text = GTK_TEXT_VIEW(textview->text);
 	int x = 0;
@@ -1952,7 +2047,8 @@ static void textview_show_xface(TextView *textview)
 
 	gtk_widget_show(textview->image);
 	
-	x = textview->text->allocation.width - WIDTH -5;
+	gtk_widget_get_allocation(textview->text, &allocation);
+	x = allocation.width - WIDTH -5;
 
 	gtk_text_view_add_child_in_window(text, textview->image, 
 		GTK_TEXT_WINDOW_TEXT, x, 5);
@@ -1970,6 +2066,7 @@ bail:
 
 static void textview_save_contact_pic(TextView *textview)
 {
+#ifndef USE_NEW_ADDRBOOK
 	MsgInfo *msginfo = textview->messageview->msginfo;
 	gchar *filename = NULL;
 	GError *error = NULL;
@@ -1993,11 +2090,14 @@ static void textview_save_contact_pic(TextView *textview)
 		}
 	}
 	g_free(filename);
+#else
+	/* new address book */
+#endif
 }
 
 static void textview_show_contact_pic(TextView *textview)
 {
-	GtkAllocation allocation;
+#ifndef USE_NEW_ADDRBOOK
 	MsgInfo *msginfo = textview->messageview->msginfo;
 	GtkTextView *text = GTK_TEXT_VIEW(textview->text);
 	int x = 0;
@@ -2049,8 +2149,7 @@ static void textview_show_contact_pic(TextView *textview)
 
 	gtk_widget_show(textview->image);
 	
-	gtk_widget_get_allocation(textview->text, &allocation);
-	x = allocation.width - WIDTH -5;
+	x = textview->text->allocation.width - WIDTH -5;
 
 	gtk_text_view_add_child_in_window(text, textview->image, 
 		GTK_TEXT_WINDOW_TEXT, x, 5);
@@ -2062,7 +2161,9 @@ bail:
 	if (textview->image) 
 		gtk_widget_destroy(textview->image);
 	textview->image = NULL;
-	
+#else
+	/* new address book */
+#endif	
 }
 
 static gint textview_tag_cmp_list(gconstpointer a, gconstpointer b)
@@ -3046,6 +3147,7 @@ static void add_uri_to_addrbook_cb (GtkAction *action, TextView *textview)
 	GtkWidget *image = NULL;
 	GdkPixbuf *picture = NULL;
 	gboolean use_picture = FALSE;
+
 	if (uri == NULL)
 		return;
 
@@ -3078,7 +3180,13 @@ static void add_uri_to_addrbook_cb (GtkAction *action, TextView *textview)
 	if (image)
 		picture = gtk_image_get_pixbuf(GTK_IMAGE(image));
 
+#ifndef USE_NEW_ADDRBOOK
 	addressbook_add_contact( fromname, fromaddress, NULL, picture);
+#else
+	if (addressadd_selection(fromname, fromaddress, NULL, picture)) {
+		debug_print( "addressbook_add_contact - added\n" );
+	}
+#endif
 
 	g_free(fromaddress);
 	g_free(fromname);
