@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2011 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 2001-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,6 +57,9 @@
 #include "prefs_toolbar.h"
 #include "alertpanel.h"
 #include "imap.h"
+#ifdef USE_NEW_ADDRBOOK
+	#include "addressbook-dbus.h"
+#endif
 
 /* elements */
 #define TOOLBAR_TAG_INDEX        "toolbar"
@@ -812,40 +815,52 @@ static void toolbar_action_execute(GtkWidget    *widget,
 			    gpointer     data,
 			    gint         source) 
 {
-	GSList *cur, *lop;
-	gchar *action, *action_p;
-	gboolean found = FALSE;
+	GSList *cur;
 	gint i = 0;
 
 	for (cur = action_list; cur != NULL;  cur = cur->next) {
 		ToolbarClawsActions *act = (ToolbarClawsActions*)cur->data;
 
 		if (widget == act->widget) {
-			
-			for (lop = prefs_common.actions_list; lop != NULL; lop = lop->next) {
-				action = g_strdup((gchar*)lop->data);
+			i = prefs_actions_find_by_name(act->name);
 
-				action_p = strstr(action, ": ");
-				action_p[0] = 0x00;
-				if (g_utf8_collate(act->name, action) == 0) {
-					found = TRUE;
-					g_free(action);
-					break;
-				} else 
-					i++;
-				g_free(action);
-			}
-			if (found) 
+			if (i != -1) 
 				break;
 		}
 	}
 
-	if (found) 
+	if (i != -1) 
 		actions_execute(data, i, widget, source);
 	else
 		g_warning ("Error: did not find Claws Action to execute");
 }
 
+gboolean toolbar_check_action_btns(ToolbarType type)
+{
+	GSList *temp, *curr, *list = toolbar_config[type].item_list;
+	gboolean modified = FALSE;
+	
+	curr = list;
+	while (curr != NULL) {
+		ToolbarItem *toolbar_item = (ToolbarItem *) curr->data;
+		temp = curr;
+		curr = curr->next;
+		
+		if (toolbar_item->index != A_CLAWS_ACTIONS)
+			continue;
+
+		if (prefs_actions_find_by_name(toolbar_item->text) == -1) {
+			list = g_slist_delete_link(list, temp);
+			g_free(toolbar_item->file);
+			g_free(toolbar_item->text);
+			g_free(toolbar_item);
+			modified = TRUE;
+		}
+	}
+	
+	return modified;
+}
+
 #if !(GTK_CHECK_VERSION(2,12,0))
 #define CLAWS_SET_TOOL_ITEM_TIP(widget,tip) { \
 	gtk_tool_item_set_tooltip(GTK_TOOL_ITEM(widget), GTK_TOOLTIPS(toolbar_tips),	\
@@ -1303,7 +1318,17 @@ static void toolbar_addrbook_cb(GtkWidget *widget, gpointer data)
 	default:
 		return;
 	}
+#ifndef USE_NEW_ADDRBOOK
 	addressbook_open(compose);
+#else
+	GError* error = NULL;
+	addressbook_connect_signals(compose);
+	addressbook_dbus_open(TRUE, &error);
+	if (error) {
+		g_warning("%s", error->message);
+		g_error_free(error);
+	}
+#endif
 }
 
 
@@ -2348,11 +2373,11 @@ void toolbar_main_set_sensitive(gpointer data)
 	
 	if (toolbar->get_btn)
 		SET_WIDGET_COND(toolbar->get_btn, 
-			M_HAVE_ACCOUNT|M_UNLOCKED);
+			M_HAVE_ACCOUNT|M_UNLOCKED|M_HAVE_RETRIEVABLE_ACCOUNT);
 
 	if (toolbar->getall_btn) {
 		SET_WIDGET_COND(toolbar->getall_btn, 
-			M_HAVE_ACCOUNT|M_UNLOCKED);
+			M_HAVE_ACCOUNT|M_UNLOCKED|M_HAVE_ANY_RETRIEVABLE_ACCOUNT);
 	}
 	if (toolbar->send_btn) {
 		SET_WIDGET_COND(toolbar->send_btn,
